@@ -307,7 +307,7 @@
 #' @returns A string. The URL.
 #'
 #' @noRd
-.formaURLSIOP <- function(query, timeout) {
+.formaURLSIOP <- function(query, timeout = 0) {
   query <- gsub("\n", " ", query) # Remove newline characters
   query <- gsub("\\s+", " ", query)
   query <- utils::URLencode(query, TRUE, TRUE)
